@@ -6,7 +6,7 @@ import base64
 from .option import Option
 
 @Option.wrap
-def read_base64_image(uri:str):
+def base64_to_image(uri:str):
    
    split_uri = uri.split(',') 
    
